@@ -9,6 +9,9 @@ class Scraper:
         self.on_close()
 
     def wget(self, url, tries=0):
+        self.parser = self.on_wget(url)
+        return True
+
         try:
             if url is not None and tries < 3:
                 self.parser = self.on_wget(url)
